SET SESSION TRANSACTION ISOLATION LEVEL SERIALIZABLE;
SET SESSION sql_mode = 'ANSI';
DROP schema IF EXISTS RZ_DICOM;
CREATE schema RZ_DICOM;
USE RZ_DICOM;
SET GLOBAL TRANSACTION ISOLATION LEVEL SERIALIZABLE;
SET GLOBAL sql_mode = 'ANSI';
CREATE TABLE N_PATIENT (
	id INTEGER PRIMARY KEY AUTO_INCREMENT NOT NULL,
	patient_id char(64) NULL,
	patient_message_id integer NULL,
	patient_name varchar(100) NULL,
	phone_number varchar(100) NULL,
	birth_date date NULL,
	sex char(1) NULL,
	address varchar(100) NULL,
	ssn char(18) NULL,
    patient_other_id char(64) NULL
	);

CREATE TABLE REQUESTED_PROCEDURE (
	id INTEGER PRIMARY KEY AUTO_INCREMENT NOT NULL,
	study_instance_uid char(64) NULL,
	req_proc_desc char(64) NULL,
	req_proc_id char(50) NULL,
	service_request_id integer NULL,
	patient_internal_id integer NULL,
	RequestedProcedureCodeSequence integer NULL
	);

CREATE TABLE SERVICE_REQUEST (
	id INTEGER PRIMARY KEY AUTO_INCREMENT NOT NULL,
	accession_number char(50) NULL,
	referring_physicians_names varchar(100) NULL,
	requesting_physician varchar(100) NULL,
	requesting_service varchar(100) NULL);

CREATE TABLE SCHED_PROC_STEP(
	id INTEGER PRIMARY KEY AUTO_INCREMENT NOT NULL,
	modality char(16) NULL,
	scheduled_station_ae_title char(16) NULL,
	start_date_time datetime NULL,
	end_date_time datetime NULL,
	perf_phys_name varchar(100) NULL,
	sched_proc_step_desc char(64) NULL,
	sched_proc_step_id char(16) NULL,
	req_proc_id integer NOT NULL);

CREATE TABLE CONFIGURATION(
	`key` char(50) NOT NULL,
	`value` char(50) NOT NULL,
	Description varchar(100) NULL);

CREATE TABLE DICOM_FILES(
	file_id INTEGER PRIMARY KEY AUTO_INCREMENT NOT NULL,
	creation_time datetime NOT NULL DEFAULT NOW(),
	update_time date NULL,
	patient_name char(64) NOT NULL,
	patient_id char(64) NOT NULL,
	patient_sex char(1) NULL,
	patient_birth_date date NULL,
	study_instance_uid char(64) NOT NULL,
	study_id char(16) NULL,
	study_date_time datetime NULL,
	accession_number char(16) NULL,
	modality char(16) NULL,
	series_number char(16) NULL,
	series_instance_uid char(64) NOT NULL,
	instance_number char(16) NULL,
	sop_class_uid char(64) NOT NULL,
	sop_instance_uid char(64) NOT NULL,
	source_ae_title char(64) NULL,
	rel_path varchar(100) NOT NULL,
	task_id integer NULL);



CREATE VIEW CFIND_MWL_VIEW
AS
SELECT REQUESTED_PROCEDURE.study_instance_uid AS StudyInstanceUID, REQUESTED_PROCEDURE.req_proc_desc AS RequestedProcedureDescription, REQUESTED_PROCEDURE.id AS ScheduledProcedureStepSequence, 
            REQUESTED_PROCEDURE.req_proc_id AS RequestedProcedureID, SERVICE_REQUEST.accession_number AS AccessionNumber, SERVICE_REQUEST.referring_physicians_names AS ReferringPhysicianName, 
            SERVICE_REQUEST.requesting_physician AS RequestingPhysician, N_PATIENT.patient_id AS PatientID, N_PATIENT.patient_name AS PatientName, N_PATIENT.birth_date AS PatientBirthDate, N_PATIENT.sex AS PatientSex, patient_other_id AS OtherPatientID, NULL 
            AS PatientWeight, NULL AS MedicalAlerts, NULL AS Allergies, NULL AS PregnancyStatus, NULL AS RequestedContrastAgent, NULL AS AdmissionID, NULL AS SpecialNeeds, NULL AS CurrentPatientLocation, NULL AS PatientState, NULL AS RequestedProcedurePriority, NULL 
            AS PatientTransportArrangements, NULL AS ConfidentialityConstraintOnPatientDataDescription, SERVICE_REQUEST.requesting_service
FROM    REQUESTED_PROCEDURE INNER JOIN
            SERVICE_REQUEST ON REQUESTED_PROCEDURE.service_request_id = SERVICE_REQUEST.id INNER JOIN
            N_PATIENT ON REQUESTED_PROCEDURE.patient_internal_id = N_PATIENT.id;

CREATE VIEW CFIND_ScheduledProcedureStepSequence_VIEW
AS
SELECT        
	id, 
	modality, 
	scheduled_station_ae_title AS ScheduledStationAETitle, 
	DATE(start_date_time) AS ScheduledProcedureStepStartDate, 
    perf_phys_name AS ScheduledPerformingPhysicianName, 
    req_proc_id AS ScheduledProcedureStepSequence, 
    TIME(start_date_time) AS ScheduledProcedureStepStartTime, 
    sched_proc_step_desc AS ScheduledProcedureStepDescription, 
    'SPSID' || CAST(id AS char) AS ScheduledProcedureStepID, 
    NULL AS ScheduledPerformingPhysiciansName, 
    NULL AS ScheduledStationName, 
    NULL AS ScheduledProcedureStepLocation, 
    NULL AS PreMedication,
	start_date_time AS ScheduledProcedureStepStartDateTime, 
    DATE(end_date_time) AS ScheduledProcedureStepEndDate, 
    TIME(end_date_time) AS ScheduledProcedureStepEndTime, 
    end_date_time AS DateTime
FROM            
	SCHED_PROC_STEP;

CREATE VIEW CFIND_SERIES_VIEW
AS
SELECT DISTINCT 
                      patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID
FROM         DICOM_FILES;

CREATE VIEW CFIND_IMAGE_VIEW
AS
SELECT DISTINCT 
                patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID, 
				instance_number AS InstanceNumber,
                sop_class_uid AS SOPClassUID, sop_instance_uid AS SOPInstanceUID
FROM         DICOM_FILES;

CREATE VIEW CFIND_STUDY_VIEW
AS
SELECT DISTINCT patient_name AS PatientName, patient_id AS PatientID, study_id AS StudyID,
                DICOM_FILES.study_date_time AS StudyDate,
                DICOM_FILES.study_date_time AS StudyTime, accession_number AS AccessionNumber, study_instance_uid AS StudyInstanceUID, patient_sex AS PatientSex, patient_birth_date AS PatientBirthDate,
                (SELECT CAST(COUNT(SeriesInstanceUID) as char(12)) FROM CFIND_SERIES_VIEW WHERE (StudyInstanceUID = DICOM_FILES.study_instance_uid)) AS NumberOfStudyRelatedSeries,
                (SELECT CAST(COUNT(SOPInstanceUID) as char(12)) FROM    CFIND_IMAGE_VIEW WHERE (StudyInstanceUID = DICOM_FILES.study_instance_uid)) AS NumberOfStudyRelatedInstances,
                (SELECT DISTINCT Modality + '\'' AS 'data()' FROM    CFIND_IMAGE_VIEW AS CFIND_IMAGE_VIEW_1 WHERE  (StudyInstanceUID = DICOM_FILES.study_instance_uid) ) AS ModalitiesInStudy
FROM    DICOM_FILES;

CREATE VIEW CFIND_PATIENT_VIEW
AS
SELECT DISTINCT 
    patient_name AS PatientName, 
	patient_id AS PatientID, 
	patient_sex AS PatientSex, 
	patient_birth_date AS PatientBirthDate
FROM         DICOM_FILES;

CREATE VIEW CMOVE_PATIENT_VIEW
AS
SELECT DISTINCT 
                      DICOM_FILES.patient_name AS PatientsName, DICOM_FILES.patient_id AS PatientID, 
                      CONCAT(CONFIGURATION.Value , '\\' , DICOM_FILES.rel_path) AS file_path
FROM         DICOM_FILES CROSS JOIN
                      CONFIGURATION
WHERE     (CONFIGURATION.`Key` = 'root_dir');

CREATE VIEW CMOVE_STUDY_VIEW
AS
SELECT DISTINCT 
                patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, CONCAT(CONFIGURATION.Value , '\\' , DICOM_FILES.rel_path) AS file_path
FROM         DICOM_FILES CROSS JOIN
                      CONFIGURATION
WHERE     (CONFIGURATION.`Key` = 'root_dir');

CREATE VIEW CMOVE_SERIES_VIEW
AS
SELECT DISTINCT 
                      patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID, 
                      CONCAT(CONFIGURATION.Value , '\\' , DICOM_FILES.rel_path) AS file_path
FROM         DICOM_FILES CROSS JOIN
                      CONFIGURATION
WHERE     (CONFIGURATION.`Key` = 'root_dir');

CREATE VIEW CMOVE_IMAGE_VIEW
AS
SELECT DISTINCT 
                      patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID, 
				instance_number AS InstanceNumber,
                sop_class_uid AS SOPClassUID, sop_instance_uid AS SOPInstanceUID, 
                      CONCAT(CONFIGURATION.Value , '\\' , DICOM_FILES.rel_path) AS file_path
FROM         DICOM_FILES CROSS JOIN
                      CONFIGURATION
WHERE     (CONFIGURATION.`Key` = 'root_dir');

CREATE VIEW CONFIGURATION_VIEW
AS
SELECT      
	`Key` AS confkey,
	`Value` AS confvalue,
	Description AS confdescription
FROM            
	CONFIGURATION;







