CREATE TABLE N_PATIENT (
	id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	patient_id text(64) NULL,
	patient_message_id integer NULL,
	patient_name text(400) NULL,
	phone_number text(400) NULL,
	birth_date text(8) NULL,
	sex text(1) NULL,
	address text(400) NULL,
	ssn text(18) NULL
	);

CREATE TABLE REQUESTED_PROCEDURE (
	id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	study_instance_uid text(64) NULL,
	req_proc_desc text(64) NULL,
	req_proc_id text(50) NULL,
	service_request_id integer NULL,
	patient_internal_id integer NULL,
	RequestedProcedureCodeSequence integer NULL
	);

CREATE TABLE SERVICE_REQUEST (
	id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	accession_number text(50) NULL,
	referring_physicians_names text(400) NULL,
	requesting_physician text(400) NULL,
	requesting_service text(100) NULL);

CREATE TABLE SCHED_PROC_STEP(
	id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
	modality text(16) NULL,
	scheduled_station_ae_title text(16) NULL,
	start_date_time text(23) NULL,
	end_date_time text(23) NULL,
	perf_phys_name text(250) NULL,
	sched_proc_step_desc text(64) NULL,
	sched_proc_step_id text(16) NULL,
	req_proc_id integer NOT NULL);

CREATE TABLE CONFIGURATION(
	Key text(50) NOT NULL,
	Value text(50) NOT NULL,
	Description text(400) NULL);

CREATE TABLE DICOM_FILES(
	file_id integer primary key asc NOT NULL,
	creation_time text(8) NOT NULL default (date('now')),
	update_time text(8) NULL,
	patient_name text(64) NOT NULL,
	patient_id text(64) NOT NULL,
	patient_sex text(1) NULL,
	patient_birth_date text(8) NULL,
	study_instance_uid text(64) NOT NULL,
	study_id text(16) NULL,
	study_date_time text(23) NULL,
	accession_number text(16) NULL,
	modality text(16) NULL,
	series_number text(16) NULL,
	series_instance_uid text(64) NOT NULL,
	instance_number text(16) NULL,
	sop_class_uid text(64) NOT NULL,
	sop_instance_uid text(64) NOT NULL,
	source_ae_title text(64) NULL,
	rel_path text(400) NOT NULL,
	task_id integer NULL);



CREATE VIEW CFIND_MWL_VIEW
AS
SELECT REQUESTED_PROCEDURE.study_instance_uid AS StudyInstanceUID, REQUESTED_PROCEDURE.req_proc_desc AS RequestedProcedureDescription, REQUESTED_PROCEDURE.id AS ScheduledProcedureStepSequence, 
            REQUESTED_PROCEDURE.req_proc_id AS RequestedProcedureID, SERVICE_REQUEST.accession_number AS AccessionNumber, SERVICE_REQUEST.referring_physicians_names AS ReferringPhysicianName, 
            SERVICE_REQUEST.requesting_physician AS RequestingPhysician, N_PATIENT.patient_id AS PatientID, N_PATIENT.patient_name AS PatientName, N_PATIENT.birth_date AS PatientBirthDate, N_PATIENT.sex AS PatientSex, NULL 
            AS PatientWeight, NULL AS MedicalAlerts, NULL AS Allergies, NULL AS PregnancyStatus, NULL AS RequestedContrastAgent, NULL AS AdmissionID, NULL AS SpecialNeeds, NULL AS CurrentPatientLocation, NULL AS PatientState, NULL AS RequestedProcedurePriority, NULL 
            AS PatientTransportArrangements, NULL AS ConfidentialityConstraintOnPatientDataDescription, SERVICE_REQUEST.requesting_service
FROM    REQUESTED_PROCEDURE INNER JOIN
            SERVICE_REQUEST ON REQUESTED_PROCEDURE.service_request_id = SERVICE_REQUEST.id INNER JOIN
            N_PATIENT ON REQUESTED_PROCEDURE.patient_internal_id = N_PATIENT.id;

CREATE VIEW CFIND_ScheduledProcedureStepSequence_VIEW
AS
SELECT        
	id, 
	modality, 
	scheduled_station_ae_title AS ScheduledStationAETitle, 
	DATE(start_date_time) AS ScheduledProcedureStepStartDate, 
    perf_phys_name AS ScheduledPerformingPhysicianName, 
    req_proc_id AS ScheduledProcedureStepSequence, 
    TIME(start_date_time) AS ScheduledProcedureStepStartTime, 
    sched_proc_step_desc AS ScheduledProcedureStepDescription, 
    'SPSID' || CAST(id AS text) AS ScheduledProcedureStepID, 
    NULL AS ScheduledPerformingPhysiciansName, 
    NULL AS ScheduledStationName, 
    NULL AS ScheduledProcedureStepLocation, 
    NULL AS PreMedication,
	start_date_time AS ScheduledProcedureStepStartDateTime, 
    DATE(end_date_time) AS ScheduledProcedureStepEndDate, 
    TIME(end_date_time) AS ScheduledProcedureStepEndTime, 
    end_date_time AS DateTime
FROM            
	SCHED_PROC_STEP;

CREATE VIEW CFIND_SERIES_VIEW
AS
SELECT DISTINCT 
                      patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID
FROM         DICOM_FILES;

CREATE VIEW CFIND_IMAGE_VIEW
AS
SELECT DISTINCT 
                patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID, 
				instance_number AS InstanceNumber,
                sop_class_uid AS SOPClassUID, sop_instance_uid AS SOPInstanceUID
FROM         DICOM_FILES;

CREATE VIEW CFIND_STUDY_VIEW
AS
SELECT DISTINCT patient_name AS PatientName, patient_id AS PatientID, study_id AS StudyID,
                DICOM_FILES.study_date_time AS StudyDate,
                DICOM_FILES.study_date_time AS StudyTime, accession_number AS AccessionNumber, study_instance_uid AS StudyInstanceUID, patient_sex AS PatientSex, patient_birth_date AS PatientBirthDate,
                (SELECT COUNT(SeriesInstanceUID) FROM CFIND_SERIES_VIEW WHERE (StudyInstanceUID = DICOM_FILES.study_instance_uid)) AS NumberOfStudyRelatedSeries,
                (SELECT COUNT(SOPInstanceUID) FROM    CFIND_IMAGE_VIEW WHERE (StudyInstanceUID = DICOM_FILES.study_instance_uid)) AS NumberOfStudyRelatedInstances,
                (SELECT DISTINCT Modality + '\' AS 'data()' FROM    CFIND_IMAGE_VIEW AS CFIND_IMAGE_VIEW_1 WHERE  (StudyInstanceUID = DICOM_FILES.study_instance_uid) ) AS ModalitiesInStudy
FROM    DICOM_FILES;

CREATE VIEW CFIND_PATIENT_VIEW
AS
SELECT DISTINCT 
    patient_name AS PatientName, 
	patient_id AS PatientID, 
	patient_sex AS PatientSex, 
	patient_birth_date AS PatientBirthDate
FROM         DICOM_FILES;

CREATE VIEW CMOVE_PATIENT_VIEW
AS
SELECT DISTINCT 
                      DICOM_FILES.patient_name AS PatientsName, DICOM_FILES.patient_id AS PatientID, 
                      CONFIGURATION.Value + '\' + DICOM_FILES.rel_path AS file_path
FROM         DICOM_FILES CROSS JOIN
                      CONFIGURATION
WHERE     (CONFIGURATION.Key = 'root_dir');

CREATE VIEW CMOVE_STUDY_VIEW
AS
SELECT DISTINCT 
                patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, CONFIGURATION.Value + '\' + DICOM_FILES.rel_path AS file_path
FROM         DICOM_FILES CROSS JOIN
                      CONFIGURATION
WHERE     (CONFIGURATION.Key = 'root_dir');

CREATE VIEW CMOVE_SERIES_VIEW
AS
SELECT DISTINCT 
                      patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID, 
                      CONFIGURATION.Value + '\' + DICOM_FILES.rel_path AS file_path
FROM         DICOM_FILES CROSS JOIN
                      CONFIGURATION
WHERE     (CONFIGURATION.Key = 'root_dir');

CREATE VIEW CMOVE_IMAGE_VIEW
AS
SELECT DISTINCT 
                      patient_name AS PatientsName, patient_id AS PatientID, 
				study_id AS StudyID, study_date_time AS StudyDate,
				accession_number AS AccessionNumber,
				study_instance_uid AS StudyInstanceUID, modality AS Modality,
				series_number AS SeriesNumber,
				series_instance_uid AS SeriesInstanceUID, 
				instance_number AS InstanceNumber,
                sop_class_uid AS SOPClassUID, sop_instance_uid AS SOPInstanceUID, 
                      CONFIGURATION.Value + '\' + DICOM_FILES.rel_path AS file_path
FROM         DICOM_FILES CROSS JOIN
                      CONFIGURATION
WHERE     (CONFIGURATION.Key = 'root_dir');

CREATE VIEW CONFIGURATION_VIEW
AS
SELECT      
	Key AS confkey,
	Value AS confvalue,
	Description AS confdescription
FROM            
	CONFIGURATION;

INSERT INTO N_PATIENT
           (id 
           ,patient_id
           ,patient_name
           ,birth_date
           ,sex)
     VALUES
           (123456789
           ,'123456789'
           ,'AB^CD'
           ,'1/1/1956'
           ,'M');

INSERT INTO SERVICE_REQUEST
           (id
           ,accession_number
           ,referring_physicians_names
           ,requesting_physician)
     VALUES
           (2121
           ,'RRZ000000000001'
           ,'Physician^Referring'
           ,'Physician^Requesting');




INSERT INTO REQUESTED_PROCEDURE
           (id
           ,study_instance_uid
           ,req_proc_desc
           ,service_request_id
           ,patient_internal_id)
     VALUES
           (1212
           ,'1.2.3.4.5.6.7.8'
           ,'Requested procedure description'
           ,2121
           ,123456789);

INSERT INTO SCHED_PROC_STEP
           (id
           ,modality
           ,scheduled_station_ae_title
           ,start_date_time
           ,end_date_time
           ,perf_phys_name
           ,sched_proc_step_desc
           ,sched_proc_step_id
           ,req_proc_id)
     VALUES
           (1234
           ,'CR'
           ,'TESTCR'
           ,'2016-02-01 16:30:00.000'
           ,'2016-02-01 17:00:00.000'
           ,'Performing Physician Name'
           ,'Secheduled Procedure Step Description'
           ,'SPSID1'
           ,1212);

/****** Insert data into the CONFIGURATION table ******/
INSERT INTO CONFIGURATION (Key,Value,Description) VALUES ('ae_title', 'DSRSVC', 'Local ae title');
INSERT INTO CONFIGURATION (Key,Value,Description) VALUES ('port', '104', 'Listener port');
INSERT INTO CONFIGURATION (Key,Value,Description) VALUES ('retry_seconds', '180', 'The number of seconds to wait before retrying a failed task');
INSERT INTO CONFIGURATION (Key,Value,Description) VALUES ('root_dir', '\DSRSVC', 'Working file system directory');
INSERT INTO CONFIGURATION (Key,Value,Description) VALUES ('scm_max_retry', '3', 'The maximum number of retries for sending back commit responses');
INSERT INTO CONFIGURATION (Key,Value,Description) VALUES ('dicom_log', '0', 'When this value is 1, detailed logging is on');




